@@ -13,7 +13,6 @@ use serde::{Deserialize, Serialize};
 use shipping::{FulfillmentType, FulfillmentTypeSelection, ShippingCalculator, ShippingQuote};
 use std::matches;
 use uuid::Uuid;
-use dropshot::{ApiDescription, ServerContext, HttpServerStarter};
 
 pub use chrono::{DateTime, Utc};
 pub use http;
@@ -321,12 +320,6 @@ pub trait ContextProvider {
     async fn new_context(&self) -> Result<Self::Context, Error>;
 }
 
-pub trait Server: ContextProvider {
-    type Context: ServerContext;
-    fn api_description() -> ApiDescription<<Self as Server>::Context>;
-    fn new_server(self, bind_address: &str) -> Result<HttpServerStarter<<Self as Server>::Context>, Error>;
-}
-
 fn new_invalid_state_error(msg: &str) -> Error {
     Error {
         code: String::from("300"),
